@@ -345,6 +345,14 @@ void thexpmodel::export_3d_file(class thdatabase * dbp)
       if (!tmps->is_temporary())
         img_write_item(pimg, img_LABEL, x_exp, stnbuf,
           dbp->db1d.station_vec[i].x, dbp->db1d.station_vec[i].y, dbp->db1d.station_vec[i].z);
+      else {
+        x_exp |= img_SFLAG_ANON;
+        if (tmps->temps == TT_TEMPSTATION_WALL)
+          x_exp |= img_SFLAG_WALL;        
+        img_write_item(pimg, img_LABEL, x_exp, "",
+          dbp->db1d.station_vec[i].x, dbp->db1d.station_vec[i].y, dbp->db1d.station_vec[i].z);
+      
+      }
     }
   }
   
@@ -743,7 +751,7 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          srfc = ((thsurface*)(*obi));
+          srfc = ((thsurface*)(*obi).get());
           tmp3d = srfc->get_3d();
           srfc->calibrate();
           tinv = srfc->calib_yy*srfc->calib_xx - srfc->calib_xy*srfc->calib_yx;
@@ -766,7 +774,7 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
                   fseek(xf, 0, SEEK_SET);
                   if (fsz > 0) {
                     char * cdata = new char [fsz];
-                    fread((void *) cdata, 1, fsz, xf);
+                    thassert(fread((void *) cdata, 1, fsz, xf) == fsz);
                     fwrite((void *) cdata, 1, fsz, texf);
                     delete [] cdata;
                   }
@@ -1004,7 +1012,7 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          tmp3d = ((thsurface*)(*obi))->get_3d();
+          tmp3d = ((thsurface*)(*obi).get())->get_3d();
           if (tmp3d != NULL) {
             tmp3d->exp_shift_x = avx;
             tmp3d->exp_shift_y = avy;
@@ -1347,7 +1355,7 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          tmp3d = ((thsurface*)(*obi))->get_3d();
+          tmp3d = ((thsurface*)(*obi).get())->get_3d();
           if (tmp3d != NULL) {
             tmp3d->exp_shift_x = avx;
             tmp3d->exp_shift_y = avy;
@@ -1484,7 +1492,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi);
+      sptr = (thsurvey*)(*obi).get();
       if (sptr->is_selected()) {
         sptr->num1 = 1;
       } else {
@@ -1526,7 +1534,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi);
+      sptr = (thsurvey*)(*obi).get();
       if ((sptr->num1 > 0) && (sptr->fsptr != NULL)) {
         tsptr = sptr->fsptr;
         if (tsptr->num1 > 0)
@@ -1553,7 +1561,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi);
+      sptr = (thsurvey*)(*obi).get();
       if (sptr->num1 > 0) {
         sptr->num1 = survnum++;
         expf_survey.m_id = sptr->num1;
@@ -1649,7 +1657,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          csrf = ((thsurface*)(*obi));
+          csrf = ((thsurface*)(*obi).get());
           tmp3d = csrf->get_3d();
           if ((tmp3d != NULL) && (tmp3d->nfaces > 0)) {
             expf_sfc.m_id = survnum;
@@ -1991,7 +1999,7 @@ void thexpmodel::export_kml_file(class thdatabase * dbp)
 
 void thexpmodel::export_kml_survey_file(FILE * out, thsurvey * surv)
 {
-  if ((strlen(surv->name) == 0) || !(surv->is_selected()) || (surv == NULL))
+  if (!surv || (strlen(surv->name) == 0) || !(surv->is_selected()))
     return;
 
   thdataobject * obj;
@@ -2042,6 +2050,8 @@ void thexpmodel::export_kml_survey_file(FILE * out, thsurvey * surv)
               fprintf(out, "\t%.14f,%.14f,%.14f ", x / THPI * 180.0, y / THPI * 180.0, z);
               numst = 1;
             }
+            if (numst == 0)
+              fprintf(out,"<LineString><coordinates>\n");
             last_st = db->db1d.station_vec[legs->to.id - 1].uid - 1;
             thcs2cs(thcs_get_params(thcfg.outcs), thcs_get_params(TTCS_LONG_LAT),
               db->db1d.station_vec[last_st].x, db->db1d.station_vec[last_st].y, db->db1d.station_vec[last_st].z,
